@@ -9,7 +9,7 @@ use Exporter::Tidy
 use Getopt::Long qw/GetOptionsFromArray/;
 use List::Util qw/max/;
 
-our $VERSION = '0.1.17_1';
+our $VERSION = '0.1.18';
 our $COLOUR  = 0;
 our $ABBREV  = 0;
 our $SORT    = 0;
@@ -651,7 +651,7 @@ Getopt::Args - integrated argument and option processing
 
 =head1 VERSION
 
-0.1.17_1 (2015-10-22)
+0.1.18 (2015-11-27)
 
 =head1 SYNOPSIS
 
